@@ -101,7 +101,7 @@ def student_token_file_runner(host_tmp_dir, student_token_file, instructor_grade
     return pycom, token_location
 
 
-def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file, tag=None, instructor_grade_script=None, fix_user=True):
+def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file, tag=None, instructor_grade_script=None, fix_user=None):
     """
     This thingy works:
 
@@ -114,9 +114,14 @@ def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file,
 
     """
     # A bunch of tests. This is going to be great!
+    Dockerfile_location = os.path.abspath(Dockerfile_location)
     assert os.path.exists(Dockerfile_location)
+
     start = time.time()
 
+    if fix_user is None:
+        fix_user = os.name != 'nt'  # On Linux, this should probably be true to avoid problem with edit-rights of docker-created files.
+
     # with open(student_token_file, 'rb') as f:
     #     results = pickle.load(f)
     from unitgrade_private import load_token
