@@ -77,8 +77,9 @@ def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=
     pyhead = lload([evaluate.__file__, hidden_gather_upload.__file__], excl)
     from unitgrade import version
     from unitgrade import utils
+    from unitgrade import runners
     print(unitgrade.__file__)
-    report1_source = lload([unitgrade.__file__, unitgrade.framework.__file__, utils.__file__,
+    report1_source = lload([unitgrade.__file__, utils.__file__, runners.__file__, unitgrade.framework.__file__,
                             unitgrade.evaluate.__file__, hidden_gather_upload.__file__,
                             version.__file__], excl) + "\n" + report1_source
 
